summaryrefslogtreecommitdiffstats
path: root/src/sbefw/sbescom.H
diff options
context:
space:
mode:
Diffstat (limited to 'src/sbefw/sbescom.H')
-rw-r--r--src/sbefw/sbescom.H13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/sbefw/sbescom.H b/src/sbefw/sbescom.H
index 802a4c88..7241634f 100644
--- a/src/sbefw/sbescom.H
+++ b/src/sbefw/sbescom.H
@@ -23,17 +23,18 @@
/* */
/* IBM_PROLOG_END_TAG */
+#include "sbeSpMsg.H"
/**
* @brief check if scom address is Indirect scom and perform scom
*
* @param[in] i_isRead True if read operation, false otherwise
* @param[in] i_addr scom addess
* @param[in] io_data data for scom operation. For read, it is output operand.
* @param[in] o_pcbPibStatus pcbpib status
*
- * @return seconday error code.
+ * @return seconday error code.
*/
uint32_t checkIndirectAndDoScom( const bool i_isRead,
const uint64_t i_addr,
uint64_t & io_data,
- uint32_t & o_pcbPibStatus );
+ sbeResponseFfdc_t *const o_ffdc);
OpenPOWER on IntegriCloud
@@ -23,17 +23,18 @@
* @brief check if scom address is Indirect scom and perform scom
*
- * @param[in] i_isRead True if read operation, false otherwise
- * @param[in] i_addr scom addess
- * @param[in] io_data data for scom operation. For read, it is output operand.
- * @param[in] o_pcbPibStatus pcbpib status
+ * @param[in] i_isRead True if read operation, false otherwise
+ * @param[in] i_addr scom addess
+ * @param[in] io_data data for scom operation. For read, it is output operand.
+ * @param[out] o_ffdc ffdc object
*